@@ -63,7 +63,7 @@ static void dirpath(bool middle, String path, bool top = true)
         output(middle, path);
 }
 
-extern "C" int main(int argc, char **argv)
+PROGRAM_MAIN(argc, argv)
 {
     unsigned count = 0;
     char *ep;
@@ -78,11 +78,11 @@ extern "C" int main(int argc, char **argv)
         printf("%s\n", _TEXT("Options:"));
         shell::help();
         printf("\n%s\n", _TEXT("Report bugs to dyfet@gnu.org"));
-        exit(0);
+        PROGRAM_EXIT(0);
     }
 
     if(!args())
-        return 0;
+        PROGRAM_EXIT(0);
 
     if(quote[0]) {
         if(!quote[1]) {
@@ -131,6 +131,6 @@ extern "C" int main(int argc, char **argv)
     if(!lines)
         shell::printf("\n");
 
-    return 0;
+    PROGRAM_EXIT(0);
 }
 
