@@ -47,7 +47,7 @@ static void zerofill(void)
 
     fs.create("zerofill.tmp", fsys::ACCESS_STREAM, 0666);
     if(!is(fs))
-        shell::errexit(1, "zerofill: %s\n",
+        shell::errexit(1, "*** zerofill: %s\n",
             _TEXT("cannot create temporary file"));
 
     live = true;
@@ -74,7 +74,7 @@ static void zerofill(void)
     cleanup();
 
     if(fs.err() != ENOSPC)
-        shell::errexit(3, "zerofill: %s\n",
+        shell::errexit(3, "*** zerofill: %s\n",
             _TEXT("failed before end of space"));
 }
 
@@ -87,16 +87,16 @@ static void zerofill(const char *devname)
     fsys_t fs;
 
     if(fsys::stat(devname, &ino))
-        shell::errexit(5, "zerofill: %s: %s\n",
+        shell::errexit(5, "*** zerofill: %s: %s\n",
             devname, _TEXT("cannot access"));
 
     if(!fsys::isdisk(&ino))
-        shell::errexit(6, "zerofill: %s: %s\n",
+        shell::errexit(6, "*** zerofill: %s: %s\n",
             devname, _TEXT("not block device"));
 
     fs.open(devname, fsys::ACCESS_WRONLY);
     if(fs.err())
-        shell::errexit(5, "zerofill: %s: %s\n",
+        shell::errexit(5, "*** zerofill: %s: %s\n",
             devname, _TEXT("cannot modify"));
 
     shell::printf("%s", devname);
@@ -125,18 +125,18 @@ static void zerofill(const char *devname)
     cleanup();
 
     if(fs.err() != ENOSPC)
-        shell::errexit(3, "zerofill: %s\n",
+        shell::errexit(3, "*** zerofill: %s\n",
             _TEXT("failed before end of space"));
 }
 
-extern "C" int main(int argc, char **argv)
+PROGRAM_MAIN(argc, argv)
 {
     shell::bind("zerofill");
     shell args(argc, argv);
     unsigned count = 0;
 
     if(*passes < 0)
-        shell::errexit(2, "zerofill: random: %ld: %s\n",
+        shell::errexit(2, "*** zerofill: random: %ld: %s\n",
             *passes, _TEXT("negative random passes invalid"));
 
     if(is(helpflag) || is(althelp)) {
@@ -145,7 +145,7 @@ extern "C" int main(int argc, char **argv)
         printf("%s\n", _TEXT("Options:"));
         shell::help();
         printf("\n%s\n", _TEXT("Report bugs to dyfet@gnu.org"));
-        exit(0);
+        PROGRAM_EXIT(0);
     }
 
     secure::init();
@@ -158,6 +158,6 @@ extern "C" int main(int argc, char **argv)
     while(count < args() && live)
         zerofill(args[count++]);
 
-    return 0;
+    PROGRAM_EXIT(0);
 }
 
